'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Actions = require('../../Actions');

var _Icon = require('../../Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _CellTitleSelector = require('./CellTitleSelector.component');

var _CellTitleSelector2 = _interopRequireDefault(_CellTitleSelector);

var _constants = require('../utils/constants');

var _CellTitle = require('./CellTitle.scss');

var _CellTitle2 = _interopRequireDefault(_CellTitle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TITLE_MODE_TEXT = _constants.cellTitleDisplayModes.TITLE_MODE_TEXT;

/**
 * Cell that renders the item's title.
 * A title is composed by
 * - an optional icon (rowData[columnData.iconKey])
 * - a button with a click action (columnData.onClick)
 * - actions (rowData[columnData.actionsKey])
 */

function CellTitle(_ref) {
	var cellData = _ref.cellData,
	    columnData = _ref.columnData,
	    rowData = _ref.rowData,
	    rowIndex = _ref.rowIndex;
	var id = columnData.id,
	    onClick = columnData.onClick,
	    actionsKey = columnData.actionsKey,
	    displayModeKey = columnData.displayModeKey,
	    iconKey = columnData.iconKey,
	    onEditCancel = columnData.onEditCancel,
	    onEditSubmit = columnData.onEditSubmit;

	var displayMode = rowData[displayModeKey] || TITLE_MODE_TEXT;

	return _react2.default.createElement(
		'div',
		{ className: (0, _classnames2.default)('tc-list-title', _CellTitle2.default['tc-list-title']) },
		iconKey && rowData[iconKey] && _react2.default.createElement(_Icon2.default, { name: rowData[iconKey], className: _CellTitle2.default.icon }),
		_react2.default.createElement(_CellTitleSelector2.default, {
			id: id && id + '-' + rowIndex + '-title-cell',
			cellData: cellData,
			className: _CellTitle2.default['main-title'],
			displayMode: displayMode,
			onClick: onClick,
			onEditCancel: onEditCancel,
			onEditSubmit: onEditSubmit,
			rowData: rowData
		}),
		actionsKey && rowData[actionsKey] && displayMode === TITLE_MODE_TEXT && _react2.default.createElement(_Actions.Actions, {
			actions: rowData[actionsKey],
			hideLabel: true,
			link: true
		})
	);
}

CellTitle.displayName = 'VirtualizedList(CellTitle)';
CellTitle.propTypes = {
	cellData: _react.PropTypes.string,
	columnData: _react.PropTypes.shape({
		id: _react.PropTypes.string,
		onClick: _react.PropTypes.func,
		actionsKey: _react.PropTypes.string,
		displayModeKey: _react.PropTypes.string,
		iconKey: _react.PropTypes.string,
		onEditCancel: _react.PropTypes.func,
		onEditSubmit: _react.PropTypes.func
	}),
	rowData: _react.PropTypes.object, // eslint-disable-line
	rowIndex: _react.PropTypes.number
};

exports.default = CellTitle;